import { PropsWithChildren, useEffect, useRef } from 'react';

export type DialogProps = {
  onClose(): void;
  open: boolean;
};

export const Dialog = (props: PropsWithChildren<DialogProps>) => {
  const ref = useRef<HTMLDialogElement>(null);

  useEffect(() => {
    if (props.open) ref.current?.showModal();
    else ref.current?.close();
  }, [props.open]);

  return (
    <dialog className="modal" ref={ref} onClose={() => props.onClose()}>
      <form method="dialog" className="modal-box card flex gap-4">
        {props.children}
      </form>
      <form method="dialog" className="modal-backdrop">
        <button>close</button>
      </form>
    </dialog>
  );
};
